.. eleanor documentation master file, created by
   sphinx-quickstart on Mon Sep 17 11:56:28 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

eleanor: simple light curve extraction from TESS FFIs
=====================================================
.. image:: ../figures/eleanor.gif
	:height: 300px
	:width: 600px
	:align: center

eleanor is an open-source python framework for downloading, analyzing, and visualizing data from the `TESS`_ Full Frame Images.

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   getting_started/about
   getting_started/installation
   getting_started/tutorial
   getting_started/tips_tricks
   getting_started/vis_crossmatch
   getting_started/faq

.. toctree::
   :maxdepth: 2
   :caption: Documentation

   api

Bug Reports & Questions
-----------------------

eleanor is an open source project under the MIT license. The source code is available on `GitHub`_. In case of any questions or problems, please contact us via the `Git Issues`_.


Index
-----

* :ref:`genindex`

.. _TESS: https://heasarc.gsfc.nasa.gov/docs/tess/
.. _GitHub: http://github.com/afeinstein20/eleanor
.. _Git Issues: http://github.com/afeinstein20/eleanor/issues

